@@ -1,6 +1,6 @@
 import argparse
 import sys 
-from detectFacialFeatures import process_mshape
+from src.m_shape.detectFacialFeatures import process_mshape
 import cv2
 import numpy as np
 
